---
layout: doc
title: Using themes
categories: themes
permalink: /themes/install
---

IntroJS provides awesome templates and we are trying to update and add more templates for next versions. You can browse all available themes under this category.

In order to use themes, all you need to do is appending the theme stylesheet to your page, **after** IntroJS CSS file:

```html
<!-- Add IntroJs styles -->
<link href="../../introjs.css" rel="stylesheet">

<!-- Add Nazanin template -->
<link href="../../themes/introjs-nazanin.css" rel="stylesheet">
```
